@@ -37,3 +37,9 @@ class VulnerabilityManagementGateway(metaclass=ABCMeta):
         self, sbom_components, service, dict_args, secret_tool, config_tool
     ):
         "send_sbom_components"
+
+    @abstractmethod
+    def get_black_list(
+        self, dict_args, secret_tool, config_tool
+    ):
+        "get_black_list"
